@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2015, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.wildfly.extension.messaging.activemq;
@@ -37,7 +20,6 @@ import static org.wildfly.extension.messaging.activemq.MessagingExtension.SHARED
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.SHARED_STORE_SLAVE_PATH;
 
 import org.jboss.as.controller.PersistentResourceXMLDescription;
-import org.jboss.as.controller.PersistentResourceXMLDescription.PersistentResourceXMLBuilder;
 import org.jboss.as.controller.PersistentResourceXMLParser;
 import org.wildfly.extension.messaging.activemq.ha.HAAttributes;
 import org.wildfly.extension.messaging.activemq.ha.ScaleDownAttributes;
@@ -52,140 +34,21 @@ import org.wildfly.extension.messaging.activemq.jms.legacy.LegacyConnectionFacto
  * This ensures that if the resource definitions change in later version (e.g. a new attribute is added),
  * this will have no impact on parsing this specific version of the subsystem.
  *
- * @author Paul Ferraro
+ * @author <a href="http://jmesnil.net/">Jeff Mesnil</a> (c) 2015 Red Hat inc.
  */
-public class MessagingSubsystemParser_5_0 extends PersistentResourceXMLParser {
+public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
 
-    static final String NAMESPACE = "urn:jboss:domain:messaging-activemq:5.0";
+    static final String NAMESPACE = "urn:jboss:domain:messaging-activemq:2.0";
 
     @Override
     public PersistentResourceXMLDescription getParserDescription(){
-
-        final PersistentResourceXMLBuilder discoveryGroup = builder(DiscoveryGroupDefinition.PATH)
-                .addAttributes(
-                        CommonAttributes.SOCKET_BINDING,
-                        DiscoveryGroupDefinition.JGROUPS_CHANNEL_FACTORY,
-                        DiscoveryGroupDefinition.JGROUPS_CHANNEL,
-                        CommonAttributes.JGROUPS_CLUSTER,
-                        DiscoveryGroupDefinition.REFRESH_TIMEOUT,
-                        DiscoveryGroupDefinition.INITIAL_WAIT_TIMEOUT);
-
-        final PersistentResourceXMLBuilder remoteConnector = builder(pathElement(REMOTE_CONNECTOR))
-                .addAttributes(
-                        RemoteTransportDefinition.SOCKET_BINDING,
-                        CommonAttributes.PARAMS);
-
-        final PersistentResourceXMLBuilder httpConnector = builder(MessagingExtension.HTTP_CONNECTOR_PATH)
-                .addAttributes(
-                        HTTPConnectorDefinition.SOCKET_BINDING,
-                        HTTPConnectorDefinition.ENDPOINT,
-                        HTTPConnectorDefinition.SERVER_NAME,
-                        CommonAttributes.PARAMS);
-
-        final PersistentResourceXMLBuilder invmConnector = builder(pathElement(IN_VM_CONNECTOR))
-                .addAttributes(
-                        InVMTransportDefinition.SERVER_ID,
-                        CommonAttributes.PARAMS);
-
-        final PersistentResourceXMLBuilder connector = builder(pathElement(CONNECTOR))
-                .addAttributes(
-                        GenericTransportDefinition.SOCKET_BINDING,
-                        CommonAttributes.FACTORY_CLASS,
-                        CommonAttributes.PARAMS);
-
-        final PersistentResourceXMLBuilder pooledConnectionFactory =
-                                        builder(MessagingExtension.POOLED_CONNECTION_FACTORY_PATH)
-                                                .addAttributes(
-                                                        ConnectionFactoryAttributes.Common.ENTRIES,
-                                                        // common
-                                                        ConnectionFactoryAttributes.Common.DISCOVERY_GROUP,
-                                                        ConnectionFactoryAttributes.Common.CONNECTORS,
-                                                        CommonAttributes.HA,
-                                                        ConnectionFactoryAttributes.Common.CLIENT_FAILURE_CHECK_PERIOD,
-                                                        ConnectionFactoryAttributes.Common.CONNECTION_TTL,
-                                                        CommonAttributes.CALL_TIMEOUT,
-                                                        CommonAttributes.CALL_FAILOVER_TIMEOUT,
-                                                        ConnectionFactoryAttributes.Common.CONSUMER_WINDOW_SIZE,
-                                                        ConnectionFactoryAttributes.Common.CONSUMER_MAX_RATE,
-                                                        ConnectionFactoryAttributes.Common.CONFIRMATION_WINDOW_SIZE,
-                                                        ConnectionFactoryAttributes.Common.PRODUCER_WINDOW_SIZE,
-                                                        ConnectionFactoryAttributes.Common.PRODUCER_MAX_RATE,
-                                                        ConnectionFactoryAttributes.Common.PROTOCOL_MANAGER_FACTORY,
-                                                        ConnectionFactoryAttributes.Common.COMPRESS_LARGE_MESSAGES,
-                                                        ConnectionFactoryAttributes.Common.CACHE_LARGE_MESSAGE_CLIENT,
-                                                        CommonAttributes.MIN_LARGE_MESSAGE_SIZE,
-                                                        CommonAttributes.CLIENT_ID,
-                                                        ConnectionFactoryAttributes.Common.DUPS_OK_BATCH_SIZE,
-                                                        ConnectionFactoryAttributes.Common.TRANSACTION_BATCH_SIZE,
-                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_ACKNOWLEDGE,
-                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_NON_DURABLE_SEND,
-                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_DURABLE_SEND,
-                                                        ConnectionFactoryAttributes.Common.AUTO_GROUP,
-                                                        ConnectionFactoryAttributes.Common.PRE_ACKNOWLEDGE,
-                                                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL,
-                                                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL_MULTIPLIER,
-                                                        CommonAttributes.MAX_RETRY_INTERVAL,
-                                                        ConnectionFactoryAttributes.Common.RECONNECT_ATTEMPTS,
-                                                        ConnectionFactoryAttributes.Common.FAILOVER_ON_INITIAL_CONNECTION,
-                                                        ConnectionFactoryAttributes.Common.CONNECTION_LOAD_BALANCING_CLASS_NAME,
-                                                        ConnectionFactoryAttributes.Common.USE_GLOBAL_POOLS,
-                                                        ConnectionFactoryAttributes.Common.SCHEDULED_THREAD_POOL_MAX_SIZE,
-                                                        ConnectionFactoryAttributes.Common.THREAD_POOL_MAX_SIZE,
-                                                        ConnectionFactoryAttributes.Common.GROUP_ID,
-                                                        ConnectionFactoryAttributes.Common.DESERIALIZATION_BLACKLIST,
-                                                        ConnectionFactoryAttributes.Common.DESERIALIZATION_WHITELIST,
-                                                        // pooled
-                                                        // inbound config
-                                                        ConnectionFactoryAttributes.Pooled.USE_JNDI,
-                                                        ConnectionFactoryAttributes.Pooled.JNDI_PARAMS,
-                                                        ConnectionFactoryAttributes.Pooled.REBALANCE_CONNECTIONS,
-                                                        ConnectionFactoryAttributes.Pooled.USE_LOCAL_TX,
-                                                        ConnectionFactoryAttributes.Pooled.SETUP_ATTEMPTS,
-                                                        ConnectionFactoryAttributes.Pooled.SETUP_INTERVAL,
-                                                        // outbound config
-                                                        ConnectionFactoryAttributes.Pooled.ALLOW_LOCAL_TRANSACTIONS,
-
-                                                        ConnectionFactoryAttributes.Pooled.TRANSACTION,
-                                                        ConnectionFactoryAttributes.Pooled.USER,
-                                                        ConnectionFactoryAttributes.Pooled.PASSWORD,
-                                                        ConnectionFactoryAttributes.Pooled.CREDENTIAL_REFERENCE,
-                                                        ConnectionFactoryAttributes.Pooled.MIN_POOL_SIZE,
-                                                        ConnectionFactoryAttributes.Pooled.USE_AUTO_RECOVERY,
-                                                        ConnectionFactoryAttributes.Pooled.MAX_POOL_SIZE,
-                                                        ConnectionFactoryAttributes.Pooled.MANAGED_CONNECTION_POOL,
-                                                        ConnectionFactoryAttributes.Pooled.ENLISTMENT_TRACE,
-                                                        ConnectionFactoryAttributes.Common.INITIAL_MESSAGE_PACKET_SIZE,
-                                                        ConnectionFactoryAttributes.Pooled.INITIAL_CONNECT_ATTEMPTS,
-                                                        ConnectionFactoryAttributes.Pooled.STATISTICS_ENABLED);
-
         return builder(MessagingExtension.SUBSYSTEM_PATH, NAMESPACE)
                 .addAttributes(
                         MessagingSubsystemRootResourceDefinition.GLOBAL_CLIENT_THREAD_POOL_MAX_SIZE,
                         MessagingSubsystemRootResourceDefinition.GLOBAL_CLIENT_SCHEDULED_THREAD_POOL_MAX_SIZE)
-                .addChild(httpConnector)
-                .addChild(remoteConnector)
-                .addChild(invmConnector)
-                .addChild(connector)
-                .addChild(discoveryGroup)
-                .addChild(builder(MessagingExtension.CONNECTION_FACTORY_PATH)
-                        .addAttributes(
-                                CommonAttributes.HA,
-                                ConnectionFactoryAttributes.Regular.FACTORY_TYPE,
-                                ConnectionFactoryAttributes.Common.DISCOVERY_GROUP,
-                                ConnectionFactoryAttributes.Common.CONNECTORS,
-                                ConnectionFactoryAttributes.Common.ENTRIES
-                                ))
-                .addChild(pooledConnectionFactory)
-                .addChild(builder(MessagingExtension.EXTERNAL_JMS_QUEUE_PATH)
-                        .addAttributes(
-                                ConnectionFactoryAttributes.Common.ENTRIES
-                                ))
-                .addChild(builder(MessagingExtension.EXTERNAL_JMS_TOPIC_PATH)
-                        .addAttributes(
-                                ConnectionFactoryAttributes.Common.ENTRIES
-                                ))
                 .addChild(builder(MessagingExtension.SERVER_PATH)
-                                .addAttributes(// no attribute groups
+                                .addAttributes(
+                                        // no attribute groups
                                         ServerDefinition.PERSISTENCE_ENABLED,
                                         ServerDefinition.PERSIST_ID_CACHE,
                                         ServerDefinition.PERSIST_DELIVERY_COUNT_BEFORE_DELIVERY,
@@ -232,14 +95,8 @@ public class MessagingSubsystemParser_5_0 extends PersistentResourceXMLParser {
                                         ServerDefinition.JOURNAL_JMS_BINDINGS_TABLE,
                                         ServerDefinition.JOURNAL_LARGE_MESSAGES_TABLE,
                                         ServerDefinition.JOURNAL_PAGE_STORE_TABLE,
-                                        ServerDefinition.JOURNAL_NODE_MANAGER_STORE_TABLE,
                                         ServerDefinition.JOURNAL_DATABASE,
-                                        ServerDefinition.JOURNAL_JDBC_LOCK_EXPIRATION,
-                                        ServerDefinition.JOURNAL_JDBC_LOCK_RENEW_PERIOD,
                                         ServerDefinition.JOURNAL_JDBC_NETWORK_TIMEOUT,
-                                        ServerDefinition.GLOBAL_MAX_DISK_USAGE,
-                                        ServerDefinition.DISK_SCAN_PERIOD,
-                                        ServerDefinition.GLOBAL_MAX_MEMORY_SIZE,
                                         // statistics
                                         ServerDefinition.STATISTICS_ENABLED,
                                         ServerDefinition.MESSAGE_COUNTER_SAMPLE_PERIOD,
@@ -405,15 +262,30 @@ public class MessagingSubsystemParser_5_0 extends PersistentResourceXMLParser {
                                                         AddressSettingDefinition.SLOW_CONSUMER_POLICY,
                                                         AddressSettingDefinition.SLOW_CONSUMER_THRESHOLD,
                                                         AddressSettingDefinition.AUTO_CREATE_JMS_QUEUES,
-                                                        AddressSettingDefinition.AUTO_DELETE_JMS_QUEUES,
-                                                        AddressSettingDefinition.AUTO_CREATE_QUEUES,
-                                                        AddressSettingDefinition.AUTO_DELETE_QUEUES,
-                                                        AddressSettingDefinition.AUTO_CREATE_ADDRESSES,
-                                                        AddressSettingDefinition.AUTO_DELETE_ADDRESSES))
-                                .addChild(httpConnector)
-                                .addChild(remoteConnector)
-                                .addChild(invmConnector)
-                                .addChild(connector)
+                                                        AddressSettingDefinition.AUTO_DELETE_JMS_QUEUES))
+                                .addChild(
+                                        builder(MessagingExtension.HTTP_CONNECTOR_PATH)
+                                                .addAttributes(
+                                                        HTTPConnectorDefinition.SOCKET_BINDING,
+                                                        HTTPConnectorDefinition.ENDPOINT,
+                                                        HTTPConnectorDefinition.SERVER_NAME,
+                                                        CommonAttributes.PARAMS))
+                                .addChild(
+                                        builder(pathElement(REMOTE_CONNECTOR))
+                                                .addAttributes(
+                                                        RemoteTransportDefinition.SOCKET_BINDING,
+                                                        CommonAttributes.PARAMS))
+                                .addChild(
+                                        builder(pathElement(IN_VM_CONNECTOR))
+                                                .addAttributes(
+                                                        InVMTransportDefinition.SERVER_ID,
+                                                        CommonAttributes.PARAMS))
+                                .addChild(
+                                        builder(pathElement(CONNECTOR))
+                                                .addAttributes(
+                                                        GenericTransportDefinition.SOCKET_BINDING,
+                                                        CommonAttributes.FACTORY_CLASS,
+                                                        CommonAttributes.PARAMS))
                                 .addChild(
                                         builder(MessagingExtension.HTTP_ACCEPTOR_PATH)
                                                 .addAttributes(
@@ -441,11 +313,17 @@ public class MessagingSubsystemParser_5_0 extends PersistentResourceXMLParser {
                                                 .addAttributes(
                                                         CommonAttributes.SOCKET_BINDING,
                                                         BroadcastGroupDefinition.JGROUPS_CHANNEL_FACTORY,
-                                                        BroadcastGroupDefinition.JGROUPS_CHANNEL,
-                                                        CommonAttributes.JGROUPS_CLUSTER,
+                                                        CommonAttributes.JGROUPS_CHANNEL,
                                                         BroadcastGroupDefinition.BROADCAST_PERIOD,
                                                         BroadcastGroupDefinition.CONNECTOR_REFS))
-                                .addChild(discoveryGroup)
+                                .addChild(
+                                        builder(DiscoveryGroupDefinition.PATH)
+                                                .addAttributes(
+                                                        CommonAttributes.SOCKET_BINDING,
+                                                        DiscoveryGroupDefinition.JGROUPS_CHANNEL_FACTORY,
+                                                        CommonAttributes.JGROUPS_CHANNEL,
+                                                        DiscoveryGroupDefinition.REFRESH_TIMEOUT,
+                                                        DiscoveryGroupDefinition.INITIAL_WAIT_TIMEOUT))
                                 .addChild(
                                         builder(MessagingExtension.CLUSTER_CONNECTION_PATH)
                                                 .addAttributes(
@@ -571,7 +449,6 @@ public class MessagingSubsystemParser_5_0 extends PersistentResourceXMLParser {
                                                         ConnectionFactoryAttributes.Common.GROUP_ID,
                                                         ConnectionFactoryAttributes.Common.DESERIALIZATION_BLACKLIST,
                                                         ConnectionFactoryAttributes.Common.DESERIALIZATION_WHITELIST,
-                                                        ConnectionFactoryAttributes.Common.INITIAL_MESSAGE_PACKET_SIZE,
                                                         // regular
                                                         ConnectionFactoryAttributes.Regular.FACTORY_TYPE))
                                 .addChild(
@@ -614,7 +491,70 @@ public class MessagingSubsystemParser_5_0 extends PersistentResourceXMLParser {
                                                         LegacyConnectionFactoryDefinition.THREAD_POOL_MAX_SIZE,
                                                         LegacyConnectionFactoryDefinition.TRANSACTION_BATCH_SIZE,
                                                         LegacyConnectionFactoryDefinition.USE_GLOBAL_POOLS))
-                                .addChild(pooledConnectionFactory))
+                                .addChild(
+                                        builder(MessagingExtension.POOLED_CONNECTION_FACTORY_PATH)
+                                                .addAttributes(
+                                                        ConnectionFactoryAttributes.Common.ENTRIES,
+                                                        // common
+                                                        ConnectionFactoryAttributes.Common.DISCOVERY_GROUP,
+                                                        ConnectionFactoryAttributes.Common.CONNECTORS,
+                                                        CommonAttributes.HA,
+                                                        ConnectionFactoryAttributes.Common.CLIENT_FAILURE_CHECK_PERIOD,
+                                                        ConnectionFactoryAttributes.Common.CONNECTION_TTL,
+                                                        CommonAttributes.CALL_TIMEOUT,
+                                                        CommonAttributes.CALL_FAILOVER_TIMEOUT,
+                                                        ConnectionFactoryAttributes.Common.CONSUMER_WINDOW_SIZE,
+                                                        ConnectionFactoryAttributes.Common.CONSUMER_MAX_RATE,
+                                                        ConnectionFactoryAttributes.Common.CONFIRMATION_WINDOW_SIZE,
+                                                        ConnectionFactoryAttributes.Common.PRODUCER_WINDOW_SIZE,
+                                                        ConnectionFactoryAttributes.Common.PRODUCER_MAX_RATE,
+                                                        ConnectionFactoryAttributes.Common.PROTOCOL_MANAGER_FACTORY,
+                                                        ConnectionFactoryAttributes.Common.COMPRESS_LARGE_MESSAGES,
+                                                        ConnectionFactoryAttributes.Common.CACHE_LARGE_MESSAGE_CLIENT,
+                                                        CommonAttributes.MIN_LARGE_MESSAGE_SIZE,
+                                                        CommonAttributes.CLIENT_ID,
+                                                        ConnectionFactoryAttributes.Common.DUPS_OK_BATCH_SIZE,
+                                                        ConnectionFactoryAttributes.Common.TRANSACTION_BATCH_SIZE,
+                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_ACKNOWLEDGE,
+                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_NON_DURABLE_SEND,
+                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_DURABLE_SEND,
+                                                        ConnectionFactoryAttributes.Common.AUTO_GROUP,
+                                                        ConnectionFactoryAttributes.Common.PRE_ACKNOWLEDGE,
+                                                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL,
+                                                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL_MULTIPLIER,
+                                                        CommonAttributes.MAX_RETRY_INTERVAL,
+                                                        ConnectionFactoryAttributes.Common.RECONNECT_ATTEMPTS,
+                                                        ConnectionFactoryAttributes.Common.FAILOVER_ON_INITIAL_CONNECTION,
+                                                        ConnectionFactoryAttributes.Common.CONNECTION_LOAD_BALANCING_CLASS_NAME,
+                                                        ConnectionFactoryAttributes.Common.USE_GLOBAL_POOLS,
+                                                        ConnectionFactoryAttributes.Common.SCHEDULED_THREAD_POOL_MAX_SIZE,
+                                                        ConnectionFactoryAttributes.Common.THREAD_POOL_MAX_SIZE,
+                                                        ConnectionFactoryAttributes.Common.GROUP_ID,
+                                                        ConnectionFactoryAttributes.Common.DESERIALIZATION_BLACKLIST,
+                                                        ConnectionFactoryAttributes.Common.DESERIALIZATION_WHITELIST,
+                                                        // pooled
+                                                        // inbound config
+                                                        ConnectionFactoryAttributes.Pooled.USE_JNDI,
+                                                        ConnectionFactoryAttributes.Pooled.JNDI_PARAMS,
+                                                        ConnectionFactoryAttributes.Pooled.REBALANCE_CONNECTIONS,
+                                                        ConnectionFactoryAttributes.Pooled.USE_LOCAL_TX,
+                                                        ConnectionFactoryAttributes.Pooled.SETUP_ATTEMPTS,
+                                                        ConnectionFactoryAttributes.Pooled.SETUP_INTERVAL,
+                                                        // outbound config
+                                                        ConnectionFactoryAttributes.Pooled.ALLOW_LOCAL_TRANSACTIONS,
+
+                                                        ConnectionFactoryAttributes.Pooled.TRANSACTION,
+                                                        ConnectionFactoryAttributes.Pooled.USER,
+                                                        ConnectionFactoryAttributes.Pooled.PASSWORD,
+                                                        ConnectionFactoryAttributes.Pooled.CREDENTIAL_REFERENCE,
+                                                        ConnectionFactoryAttributes.Pooled.MIN_POOL_SIZE,
+                                                        ConnectionFactoryAttributes.Pooled.USE_AUTO_RECOVERY,
+                                                        ConnectionFactoryAttributes.Pooled.MAX_POOL_SIZE,
+                                                        ConnectionFactoryAttributes.Pooled.MANAGED_CONNECTION_POOL,
+                                                        ConnectionFactoryAttributes.Pooled.ENLISTMENT_TRACE,
+                                                        ConnectionFactoryAttributes.Common.INITIAL_MESSAGE_PACKET_SIZE,
+                                                        ConnectionFactoryAttributes.Pooled.INITIAL_CONNECT_ATTEMPTS,
+                                                        ConnectionFactoryAttributes.Pooled.STATISTICS_ENABLED)))
                 .addChild(
                         builder(MessagingExtension.JMS_BRIDGE_PATH)
                                 .addAttributes(
